@@ -78,14 +78,14 @@ impl File {
 
         // Bisect using indices
         // TODO: Performance of V2 could possibly be better if we would be able to do a binary search
-        // on 20 byte chunks directly, but doing so requires transmuting and that is unsafe, even though
+        // on 20 byte chunks directly, but doing so requires transmuting and that is not safe, even though
         // it should not be if the bytes match up and the type has no destructor.
         while lower_bound < upper_bound {
             let mid = (lower_bound + upper_bound) / 2;
             let mid_sha = self.id_at(file::Position(mid));
 
             use std::cmp::Ordering::*;
-            match id.cmp(&mid_sha) {
+            match id.cmp(mid_sha) {
                 Less => upper_bound = mid,
                 Equal => return Some(file::Position(mid)),
                 Greater => lower_bound = mid + 1,
