@@ -5,9 +5,8 @@ use crate::{
 };
 use byteorder::{BigEndian, ByteOrder};
 use git_hash::SIZE_OF_SHA1_DIGEST as SHA1_SIZE;
-use git_object::{borrowed, owned};
 use std::{
-    convert::{TryFrom, TryInto},
+    convert::TryInto,
     fmt::{Debug, Formatter},
     slice::Chunks,
 };
@@ -17,13 +16,13 @@ use std::{
 #[allow(missing_docs)]
 pub enum Error {
     #[error("commit {0}'s extra edges overflows the commit-graph file's extra edges list")]
-    ExtraEdgesListOverflow(owned::Id),
+    ExtraEdgesListOverflow(git_hash::ObjectId),
     #[error("commit {0}'s first parent is an extra edge index, which is invalid")]
-    FirstParentIsExtraEdgeIndex(owned::Id),
+    FirstParentIsExtraEdgeIndex(git_hash::ObjectId),
     #[error("commit {0} has extra edges, but commit-graph file has no extra edges list")]
-    MissingExtraEdgesList(owned::Id),
+    MissingExtraEdgesList(git_hash::ObjectId),
     #[error("commit {0} has a second parent but not a first parent")]
-    SecondParentWithoutFirstParent(owned::Id),
+    SecondParentWithoutFirstParent(git_hash::ObjectId),
 }
 
 // Note that git's commit-graph-format.txt as of v2.28.0 gives an incorrect value 0x0700_0000 for
@@ -40,7 +39,7 @@ pub struct Commit<'a> {
     generation: u32,
     parent1: ParentEdge,
     parent2: ParentEdge,
-    root_tree_id: borrowed::Id<'a>,
+    root_tree_id: &'a git_hash::oid,
 }
 
 impl<'a> Commit<'a> {
@@ -49,7 +48,7 @@ impl<'a> Commit<'a> {
         Commit {
             file,
             pos,
-            root_tree_id: borrowed::Id::try_from(&bytes[..SHA1_SIZE]).expect("20 bytes SHA1 to be alright"),
+            root_tree_id: git_hash::oid::try_from(&bytes[..SHA1_SIZE]).expect("20 bytes SHA1 to be alright"),
             parent1: ParentEdge::from_raw(BigEndian::read_u32(&bytes[SHA1_SIZE..SHA1_SIZE + 4])),
             parent2: ParentEdge::from_raw(BigEndian::read_u32(&bytes[SHA1_SIZE + 4..SHA1_SIZE + 8])),
             generation: BigEndian::read_u32(&bytes[SHA1_SIZE + 8..SHA1_SIZE + 12]) >> 2,
@@ -84,7 +83,7 @@ impl<'a> Commit<'a> {
     }
 
     /// Returns the hash of this commit.
-    pub fn id(&self) -> borrowed::Id<'a> {
+    pub fn id(&self) -> &'a git_hash::oid {
         self.file.id_at(self.pos)
     }
 
@@ -99,7 +98,7 @@ impl<'a> Commit<'a> {
     }
 
     /// Return the hash of the tree this commit points to.
-    pub fn root_tree_id(&self) -> borrowed::Id<'a> {
+    pub fn root_tree_id(&self) -> &git_hash::oid {
         self.root_tree_id
     }
 }
