@@ -5,11 +5,9 @@ use crate::{
 };
 use bstr::ByteSlice;
 use git_hash::SIZE_OF_SHA1_DIGEST as SHA1_SIZE;
-use git_object::{borrowed, owned};
 use std::{
     cmp::{max, min},
     collections::HashMap,
-    convert::TryFrom,
     path::Path,
 };
 
@@ -20,23 +18,32 @@ pub enum Error<E: std::error::Error + 'static> {
     #[error(transparent)]
     Commit(#[from] file::commit::Error),
     #[error("commit at file position {pos} has invalid ID {id}")]
-    CommitId { id: owned::Id, pos: file::Position },
+    CommitId {
+        id: git_hash::ObjectId,
+        pos: file::Position,
+    },
     #[error("commit at file position {pos} with ID {id} is out of order relative to its predecessor with ID {predecessor_id}")]
     CommitsOutOfOrder {
-        id: owned::Id,
+        id: git_hash::ObjectId,
         pos: file::Position,
-        predecessor_id: owned::Id,
+        predecessor_id: git_hash::ObjectId,
     },
     #[error("commit-graph filename should be {0}")]
     Filename(String),
     #[error("commit {id} has invalid generation {generation}")]
-    Generation { generation: u32, id: owned::Id },
+    Generation { generation: u32, id: git_hash::ObjectId },
     #[error("checksum mismatch: expected {expected}, got {actual}")]
-    Mismatch { actual: owned::Id, expected: owned::Id },
+    Mismatch {
+        actual: git_hash::ObjectId,
+        expected: git_hash::ObjectId,
+    },
     #[error("{0}")]
     Processor(#[source] E),
     #[error("commit {id} has invalid root tree ID {root_tree_id}")]
-    RootTreeId { id: owned::Id, root_tree_id: owned::Id },
+    RootTreeId {
+        id: git_hash::ObjectId,
+        root_tree_id: git_hash::ObjectId,
+    },
 }
 
 /// The positive result of [`File::traverse()`] providing some statistical information.
@@ -58,8 +65,8 @@ pub struct Outcome {
 /// Verification
 impl File {
     /// Returns the trailing checksum over the entire content of this file.
-    pub fn checksum(&self) -> borrowed::Id<'_> {
-        borrowed::Id::try_from(&self.data[self.data.len() - SHA1_SIZE..]).expect("file to be large enough for a hash")
+    pub fn checksum(&self) -> &git_hash::oid {
+        git_hash::oid::try_from(&self.data[self.data.len() - SHA1_SIZE..]).expect("file to be large enough for a hash")
     }
 
     /// Traverse all [commits][file::Commit] stored in this file and call `processor(commit) -> Result<(), Error>` on it.
@@ -74,7 +81,7 @@ impl File {
             .map_err(|(actual, expected)| Error::Mismatch { actual, expected })?;
         verify_split_chain_filename_hash(&self.path, self.checksum()).map_err(Error::Filename)?;
 
-        let null_id = borrowed::Id::null_sha1();
+        let null_id = git_hash::oid::null_sha1();
 
         let mut stats = Outcome {
             max_generation: 0,
@@ -85,7 +92,7 @@ impl File {
         };
 
         // TODO: Verify self.fan values as we go.
-        let mut prev_id: borrowed::Id<'a> = null_id;
+        let mut prev_id: &git_hash::oid = null_id;
         for commit in self.iter_commits() {
             if commit.id() <= prev_id {
                 if commit.id() == null_id {
@@ -136,7 +143,7 @@ impl File {
     /// checksum itself.
     ///
     /// Return the actual checksum on success or `(actual checksum, expected checksum)` if there is a mismatch.
-    pub fn verify_checksum(&self) -> Result<owned::Id, (owned::Id, owned::Id)> {
+    pub fn verify_checksum(&self) -> Result<git_hash::ObjectId, (git_hash::ObjectId, git_hash::ObjectId)> {
         // Even though we could use git_features::hash::bytes_of_file(…), this would require using our own
         // Error type to support io::Error and Mismatch. As we only gain progress, there probably isn't much value
         // as these files are usually small enough to process them in less than a second, even for the large ones.
@@ -144,10 +151,10 @@ impl File {
         let data_len_without_trailer = self.data.len() - SHA1_SIZE;
         let mut hasher = git_features::hash::Sha1::default();
         hasher.update(&self.data[..data_len_without_trailer]);
-        let actual = owned::Id::new_sha1(hasher.digest());
+        let actual = git_hash::ObjectId::new_sha1(hasher.digest());
 
         let expected = self.checksum();
-        if actual.to_borrowed() == expected {
+        if actual == expected {
             Ok(actual)
         } else {
             Err((actual, expected.into()))
@@ -157,14 +164,14 @@ impl File {
 
 /// If the given path's filename matches "graph-{hash}.graph", check that `hash` matches the
 /// expected hash.
-fn verify_split_chain_filename_hash(path: impl AsRef<Path>, expected: borrowed::Id<'_>) -> Result<(), String> {
+fn verify_split_chain_filename_hash(path: impl AsRef<Path>, expected: &git_hash::oid) -> Result<(), String> {
     let path = path.as_ref();
     path.file_name()
         .and_then(|filename| filename.to_str())
         .and_then(|filename| filename.strip_suffix(".graph"))
         .and_then(|stem| stem.strip_prefix("graph-"))
-        .map_or(Ok(()), |hex| match owned::Id::from_40_bytes_in_hex(hex.as_bytes()) {
-            Ok(actual) if actual.to_borrowed() == expected => Ok(()),
+        .map_or(Ok(()), |hex| match git_hash::ObjectId::from_hex(hex.as_bytes()) {
+            Ok(actual) if actual == expected => Ok(()),
             _ => Err(format!("graph-{}.graph", expected.to_sha1_hex().as_bstr())),
         })
 }
